##  Synchronizing Data
Data is synchronized bidirectionally between the systems. Automated synchronization is not supported. To run a synchronization manually, on the configuration page, choose the three-dot icon > Run Sync.
